<?php

  //-----------------------------------------//
  // STYLES & SCRIPTS //
  //-----------------------------------------//

  //LOAD GOOGLE FONTS
  function azurelo_fonts_url() {
      $font_url = '';
      /*
      Translators: If there are characters in your language that are not supported
      by chosen font(s), translate this to 'off'. Do not translate into your own language.
      */
      if ( 'off' !== _x( 'on', 'Google font: on or off', 'azurelo' ) ) {
          $font_url = add_query_arg( 'family', urlencode( 'Domine:400,400i|Raleway:300,400,600' ), "https://fonts.googleapis.com/css" );
      }
      return $font_url;
  }

  //LOAD CSS AND JS
  function azurelo_theme_asset() {

    // Azurelo CSS //
    wp_register_style( 'azurelo_style', get_template_directory_uri() . '/style.css', array(), '2.0.0', 'all');

    wp_enqueue_style( 'azurelo_fonts', azurelo_fonts_url() );

    wp_enqueue_style( 'azurelo_style' );

    //Azurelo JS
    wp_register_script( 'azurelo_script', get_template_directory_uri() . '/js/app.js', 'jquery', '2.0.0', true);

    wp_enqueue_script('jquery');

    wp_enqueue_script( 'azurelo_script' );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
      wp_enqueue_script( 'comment-reply' );
    }

  }

  add_action( 'wp_enqueue_scripts', 'azurelo_theme_asset' );

  //-----------------------------------------//
  // REQUIRE CRITICAL CSS + CUSTOMIZER //
  //-----------------------------------------//

  require get_template_directory() . '/css/critical_css.php';
  require get_template_directory() . '/inc/customizer.php';
  require get_template_directory() . '/inc/customizer_sanitization.php';
  require get_template_directory() . '/inc/customizer_css.php';

  //-----------------------------------------//
  // SET GLOBAL VAR NEEDED ON ALL PAGES //
  //-----------------------------------------//
  global $shared_vars;

  add_action( 'template_redirect', 'azurelo_share_var' );
  
  function azurelo_share_var() {

    if ( empty( $shared_vars ) ) {

      $shared_vars['azurelo_layout_primary_animation'] = 'false';
      $shared_vars['azurelo_layout_secondary_animation'] = 'false';
      $shared_vars['azurelo_layout_parallax_animation'] = 'false';
      $shared_vars['layout_class'] = 'right-sidebar';
      $shared_vars['layout_config'] = 'false';

      if ( get_theme_mod('azurelo_layout_primary_animation') ) { $shared_vars['azurelo_layout_primary_animation'] = 'true'; }

      if ( get_theme_mod('azurelo_layout_secondary_animation') ) { $shared_vars['azurelo_layout_secondary_animation'] = 'true'; }

      if ( get_theme_mod('azurelo_layout_parallax_animation') ) { $shared_vars['azurelo_layout_parallax_animation'] = 'true'; }

      if ( is_archive() ) {

        if ( get_theme_mod('azurelo_layout_config_archive') ) { $layout_config = get_theme_mod('azurelo_layout_config_archive'); } 
        else { $layout_config = 'right-sidebar'; }

        if ( $layout_config == 'full_layout' ) { $shared_vars['layout_class'] = 'full-layout js-full-layout'; } 
        else if ( $layout_config == 'left_sidebar' ) { $shared_vars['layout_class'] = 'left-sidebar'; }

      } else {

        if ( isset($_GET['layout_config']) ) { $layout_config = $_GET['layout_config']; } 
        else if ( get_theme_mod('azurelo_layout_config') ) { $layout_config = get_theme_mod('azurelo_layout_config'); } 
        else  { $layout_config = 'right_sidebar'; }
        
        if ( $layout_config == 'full_layout' ) { $shared_vars['layout_class'] = 'full-layout js-full-layout'; } 
        else if ( $layout_config == 'left_sidebar' ) { $shared_vars['layout_class'] = 'left-sidebar'; } 
        else { $shared_vars['layout_class'] = 'right-sidebar'; }
        
      }

      $shared_vars['layout_config'] = $layout_config;

    }

    return $shared_vars;
    
  }

  //-----------------------------------------//
  // MAKE THEME AVAILABLE FOR TRASNLATION //
  //-----------------------------------------//

  load_theme_textdomain( 'azurelo', get_template_directory() . '/lang' );


  //-----------------------------------------//
  // CONTENT WIDTH //
  //-----------------------------------------//

  if ( ! isset( $content_width ) )
    $content_width = 1200;


  //-----------------------------------------//
  // TITLE //
  //-----------------------------------------//

  function azurelo_wpdocs_filter_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) return $title;

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) )
    $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 )
    $title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'azurelo' ), max( $paged, $page ) );

    return $title;
  }

  add_filter( 'wp_title', 'azurelo_wpdocs_filter_wp_title', 10, 2 );

  function azurelo_theme_slug_setup() {
    add_theme_support( 'title-tag' );
  }

  add_action( 'after_setup_theme', 'azurelo_theme_slug_setup' );

  //-----------------------------------------//
  // MENU //
  //-----------------------------------------//
  function azurelo_register_theme_menus() {
    register_nav_menus(
      array(
        'primary-menu' => esc_html__('Primary Menu', 'azurelo')
      )
    );
  }
  add_action('init', 'azurelo_register_theme_menus');

  //-----------------------------------------//
  // POST //
  //-----------------------------------------//

  add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );

  add_theme_support( 'automatic-feed-links' );

  //algorithm function to display posts
  function azurelo_post_algorithm() {

    if ( is_archive() ) {

      $layout_display = 'default';

      if ( get_theme_mod('azurelo_layout_display_archive') ) {
        
        $layout_display = get_theme_mod('azurelo_layout_display_archive');
    
      }

    } else {

      $layout_display = 'default';

      if ( isset($_GET['layout_display']) ) {
        
        $layout_display = $_GET['layout_display'];
    
      } else if ( get_theme_mod('azurelo_layout_display') ) {
    
        $layout_display = get_theme_mod('azurelo_layout_display');
    
      }

    }

    $i = 0;
    
    if ( have_posts() ) {

      while ( have_posts() ) {

        the_post(); 

        switch ($layout_display) {

          case 'default':

            $default_posts_per_page = get_option( 'posts_per_page' );

            if ( ($i + 1) > ($default_posts_per_page - 2) ){

              get_template_part('templates/post', 'small');

            } else if ($i % 4 == 0) {

              get_template_part('templates/post', 'big');

            } else if ($i % 4 == 3) {

              get_template_part('templates/post', 'medium-inline');

            } else {

              get_template_part('templates/post', 'medium');

            }

            break;

          case 'big':

            get_template_part('templates/post', 'big');

            break;

          case 'medium':

            get_template_part('templates/post', 'medium');

            break;

          case 'medium-inline':

            get_template_part('templates/post', 'medium-inline');

            break;

          case 'small':

            get_template_part('templates/post', 'small');

            break;

        }

        $i++;

      }

    }

  }

  //-----------------------------------------//
  // PAGINATION //
  //-----------------------------------------//
  function azurelo_pagination() { ?>

    <div class="load-more">

      <?php previous_posts_link(esc_html__('Newer posts', 'azurelo')) ?>

      <?php next_posts_link(esc_html__('Older posts', 'azurelo')) ?>

    </div>

  <?php }


  //////////////////////////////////////////////////////////////////
  // THE EXCERPT
  //////////////////////////////////////////////////////////////////
  function azurelo_reset_excerpt_length( $length ) {
    return 150;
  }
  add_filter( 'excerpt_length', 'azurelo_reset_excerpt_length', 999 );

  function azurelo_excerpt($string, $nb_word) {
    $excerpt = explode(' ', $string, $nb_word);
    if (count($excerpt)>=$nb_word) {
      array_pop($excerpt);
      $excerpt = implode(" ",$excerpt).'...';
    } else {
      $excerpt = implode(" ",$excerpt);
    }
    $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
    return $excerpt;
  }

  function azurelo_wpb_set_post_views($postID) {
    $count_key = 'wpb_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
      $count = 0;
      delete_post_meta($postID, $count_key);
      add_post_meta($postID, $count_key, '0');
    }else{
      $count++;
      update_post_meta($postID, $count_key, $count);
    }
  }
  //To keep the count accurate, lets get rid of prefetching
  remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

  function azurelo_wpb_track_post_views ($post_id) {
    if ( !is_single() ) return;
    if ( empty ( $post_id) ) {
      global $post;
      $post_id = $post->ID;
    }
    azurelo_wpb_set_post_views($post_id);
  }

  add_action( 'wp_head', 'azurelo_wpb_track_post_views');


  //-----------------------------------------//
  // THUMBNAILS //
  //-----------------------------------------//

  add_theme_support('post-thumbnails');

  function azurelo_thumb() {
    add_image_size( 'azurelo_tiny', 360, 240, true );
    add_image_size( 'azurelo_small', 480, 320, true );
    add_image_size( 'azurelo_medium', 640, 427, true );
    add_image_size( 'azurelo_big', 768, 512, true );
    add_image_size( 'azurelo_full', 1160, 774, true );
    add_image_size( 'azurelo_full_hd', 1920, 1280, true );

    add_image_size( 'azurelo_square_small', 280, 280, true );
    add_image_size( 'azurelo_square_medium', 480, 480, true );
    add_image_size( 'azurelo_square_big', 640, 640, true );

    add_image_size( 'azurelo_slider_small', 640, 560, true );
    add_image_size( 'azurelo_slider_large', 1160, 560, true );
    add_image_size( 'azurelo_slider_full', 1920, 560, true );
  }

  add_action( 'after_setup_theme', 'azurelo_thumb' );

  function azurelo_post_thumbnail_responsive_size($attr, $attachment, $size = 'thumbnail') {

    if ( $size === 'azurelo_full_hd' && isset( $attr['sizes'] ) ) {

      if ( is_singular() ) {
      
        $attr['sizes'] = '100vw';

      }
    
    } else if ( $size === 'azurelo_big' && isset( $attr['sizes'] ) ) {

      if ( is_singular() ) {

        $attr['sizes'] = '(max-width: 1023px) 100vw, 1160px';

      } else {

        if ( ( isset($_GET['layout_config']) && isset($_GET['layout_config']) == 'full_layout') || get_theme_mod('azurelo_layout_config') == 'full_layout' ) {

          $attr['sizes'] = '100vw';

        } else {

          $attr['sizes'] = '(max-width: 1023px) 100vw, 740px';

        }

      }

    } else if ( $size === 'azurelo_medium' && isset( $attr['sizes'] ) ) {

      if ( ( isset($_GET['layout_config']) && isset($_GET['layout_config']) == 'full_layout') || get_theme_mod('azurelo_layout_config') == 'full_layout' ) {

        $attr['sizes'] = '(max-width: 639px) 100vw, 560px';

      } else {

        $attr['sizes'] = '(max-width: 639px) 100vw, 480px';

      }

    } else if ( $size === 'azurelo_square_small' && isset( $attr['sizes'] ) ) {

      if ( is_singular() ) {

        $attr['sizes'] = '(max-width: 639px) 100vw, 480px';

      } else {

        $attr['sizes'] = '(max-width: 1023px) 100vw, 280px';

      }

    } else if ( $size === 'azurelo_tiny' && isset( $attr['sizes'] ) ) {

      $attr['sizes'] = '(max-width: 639px) 100vw, (max-width: 1023px) 321px, 360px';

    }

    return $attr;

  }

  add_filter('wp_get_attachment_image_attributes', 'azurelo_post_thumbnail_responsive_size', 10 , 3);


  //-----------------------------------------//
  // COMMENT FORM //
  //-----------------------------------------//
  add_filter( 'comment_form_fields', 'azurelo_move_comment_field_to_bottom' );
  function azurelo_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
  }

  function azurelo_comment($comment, $args, $depth) {

    $GLOBALS['comment'] = $comment; ?>

    <?php if ($depth == 2) : ?>

      <li>

    <?php endif; ?>

    <div <?php if ($depth == 2) : comment_class('comment comment--child'); else : comment_class('comment'); endif ?> id="comment-<?php comment_ID() ?>">

      <div class="comment__container">

        <div class="comment__avatar">
          <?php echo get_avatar($comment,$args['avatar_size']); ?>
        </div>

        <div class="comment__content">

          <div class="comment__meta">

            <div class="comment__posted">

              <?php if ($depth == 2) : ?>

                <?php esc_html_e('replied by', 'azurelo'); ?>

              <?php else : ?>

                <?php esc_html_e('posted by', 'azurelo'); ?>

              <?php endif; ?>

              <?php echo get_comment_author_link() ?>

              <?php esc_html_e('on', 'azurelo'); ?> 
              
              <?php echo get_comment_date() ?>

            </div>

            <div class="comment__actions">

              <?php if( current_user_can('editor') || current_user_can('administrator') )  : ?>

                <?php edit_comment_link('<icon class="icon icon-edit"></i>'); ?>

              <?php endif; ?>

              <?php if ($comment->comment_parent == 0 ) : ?>

                <?php comment_reply_link(array_merge( $args, array('reply_text' => '<icon class="icon icon-reply"></i>', 'depth' => $depth, 'max_depth' => $args['max_depth'])), $comment->comment_ID); ?>

              <?php endif; ?>
            
            </div>

          </div>

          <?php if ($comment->comment_approved == 0) : ?>
            <div class="comment__approval">
              <p>
                <?php esc_html_e('Your comment is awaiting approval', 'azurelo'); ?>
              </p>
            </div>
          <?php endif; ?>

          <div class="comment__text">
            <?php comment_text(); ?>
          </div>

        </div>

      </div>

    </div>

    <?php if ($depth == 2) : ?>

      </li>

    <?php endif; ?>

    <?php
  }


  //-----------------------------------------//
  // SIDEBAR //
  //-----------------------------------------//

  function azurelo_widgets_init() {
    if ( function_exists('register_sidebar') ) {
      register_sidebar(array(
        'name' => __('Sidebar', 'azurelo'),
        'id' => 'sidebar',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget__heading">',
        'after_title' => '</h3>'
      ));
    }
  }

  add_action( 'widgets_init', 'azurelo_widgets_init' );

  // Widgets
  include(get_template_directory() . '/inc/widget/widget_latest.php');
  include(get_template_directory() . '/inc/widget/widget_comment.php');
  include(get_template_directory() . '/inc/widget/widget_about.php');


?>
