<?php

  /*
    Plugin Name: Azurelo About Widget
    Version: 1.0
    Description: Display informations about the blog.
  */

  function azurelo_about_load_widget() {
    register_widget( 'azurelo_about_widget' );
  }

  add_action( 'widgets_init', 'azurelo_about_load_widget' );

  class azurelo_about_widget extends WP_Widget {

    function __construct() {
      $widget_ops = array('classname' => 'widget__about-me', 'description' => 'Display informations about the blog.' );
      parent::__construct('azurelo_about_widget', 'Azurelo: About Me', $widget_ops);
      add_action('admin_enqueue_scripts', array($this, 'scripts'));
    }

    public function scripts() {
      wp_enqueue_script( 'media-upload' );
      wp_enqueue_media();
      wp_enqueue_script('azurelo_admin', get_template_directory_uri() . '/js/admin.js', array('jquery'));
    }

    function form($instance) {

      $default = array( 'title' => 'About me', 'image' => '', 'name' => '', 'description' => '', 'signature' => '');
      $instance = wp_parse_args( (array) $instance, $default );

      ?>

        <!-- Title  -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>">Title:
            <input class="widefat" id="<?php echo esc_attr(  $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
          </label>
        </p>

        <!-- Image upload -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('image') ); ?>">Image:
            <input class="widefat input-image-field" id="<?php echo esc_attr( $this->get_field_id('image') ); ?>" name="<?php echo esc_attr( $this->get_field_name('image') ); ?>" type="text" value="<?php echo esc_url($instance['image']); ?>" />
          </label>
          <button class="upload_image_button button button-primary">Upload Image</button>
        </p>

        <!-- Name -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('name') ); ?>">Name:
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('name') ); ?>" name="<?php echo esc_attr( $this->get_field_name('name') ); ?>" type="text" value="<?php echo esc_attr( $instance['name'] ); ?>" />
          </label>
        </p>

        <!-- Description -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('description') ); ?>">Description:
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id('description') ); ?>" name="<?php echo esc_attr( $this->get_field_name('description') ); ?>" type="text"><?php echo esc_html( $instance['description'] ); ?></textarea>
          </label>
        </p>

        <!-- Signature upload -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('signature') ); ?>">Signature:
            <input class="widefat input-image-field" id="<?php echo esc_attr( $this->get_field_id('signature') ); ?>" name="<?php echo esc_attr( $this->get_field_name('signature') ); ?>" type="text" value="<?php echo esc_url($instance['signature']); ?>" />
          </label>
          <button class="upload_image_button button button-primary">Upload Image</button>
        </p>



      <?php
    }

    function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = esc_attr($new_instance['title']);
      $instance['name'] = esc_attr($new_instance['name']);
      $instance['description'] = esc_attr($new_instance['description']);
      $instance['image'] = esc_attr($new_instance['image']);
      $instance['signature'] = esc_attr($new_instance['signature']);
      return $instance;
    }

    function widget($args, $instance) {

      extract($args, EXTR_SKIP);

      echo $before_widget;

      $name = isset($instance['name']) ? $instance['name'] : '';
      $description = isset($instance['description']) ? $instance['description'] : '';
      $image = esc_url(isset($instance['image']) ? $instance['image'] : '');
      $signature = esc_url(isset($instance['signature']) ? $instance['signature'] : '');

      if ( isset($instance['title'])) {
        $title = apply_filters('widget_title', $instance['title']);
        echo $before_title . esc_html( $title ) . $after_title;
      } 
      
      ?>

        <?php if ( isset($image) && $image != '' ) : ?>

          <img src="<?php echo esc_attr( $image ) ?>" alt="<?php echo esc_attr( $name ) ?>" class="about-me__img img-border">

        <?php endif; ?>

        <?php if ( isset($name) && $name != '' ) : ?>

          <h3 class="about-me__title"><?php echo esc_html( $name ) ?></h3>

        <?php endif; ?>

        <?php if ( isset($description) && $description != '' ) : ?>

          <p class="about-me__text"><?php echo esc_html( $description ) ?></p>

        <?php endif; ?>

        <?php if ( isset($signature) && $signature != '' ) : ?>

          <img src="<?php echo esc_url( $signature ) ?>" alt="<?php echo esc_attr( $name ) ?>" class="about-me__signature">

        <?php endif; ?>

      <?php echo $after_widget;

    }

  }

?>
