<?php

  /*
    Plugin Name: Azurelo Last comment Widget
    Version: 1.0
    Description: Display the last comments.
  */

  function azurelo_comment_load_widget() {
    register_widget( 'azurelo_comment_widget' );
  }

  add_action( 'widgets_init', 'azurelo_comment_load_widget' );

  class azurelo_comment_widget extends WP_Widget {

    function __construct() {
      $widget_ops = array('classname' => 'widget__comment', 'description' => 'Display the last comments.' );
      parent::__construct('azurelo_comment_widget', 'Azurelo: Last comments', $widget_ops);
    }

    function form($instance) {

      $default = array( 'title' => 'Last comments', 'nb_comment' => '4', 'is_slider' => 'off');
      $instance = wp_parse_args( (array) $instance, $default );

      ?>

        <!-- Title  -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>">Title:
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
          </label>
        </p>

        <!-- Number of posts to shows -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('nb_comment') ); ?>">Number to show:
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('nb_comment') ); ?>" name="<?php echo esc_attr( $this->get_field_name('nb_comment') ); ?>" type="number" min="1" max="4" value="<?php echo esc_attr( (int)$instance['nb_comment'] ); ?>" />
          </label>
        </p>

        <!--Use as a slider -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('is_slider') ); ?>">
          <input type="checkbox" id="<?php echo esc_attr( $this->get_field_id('is_slider') ); ?>" name="<?php echo esc_attr( $this->get_field_name('is_slider') ); ?>" <?php checked( (bool) $instance['is_slider'], true ); ?>">
          Use as a slider
        </p>


      <?php
    }

    function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = esc_attr($new_instance['title']);
      $instance['nb_comment'] = esc_attr($new_instance['nb_comment']);
      $instance['is_slider'] = esc_attr($new_instance['is_slider']);
      return $instance;
    }

    function widget($args, $instance) {

      extract($args, EXTR_SKIP);

      echo $before_widget;

      $nb_comment = (isset($instance['nb_comment']) ? $instance['nb_comment'] : '');
      $is_slider = isset($instance['is_slider']) ? $instance['is_slider'] : '';

      if ( isset($instance['title'])) {
        $title = apply_filters('widget_title', $instance['title']);
        echo $before_title . esc_html( $title ) . $after_title;
      } 
      
      $args = array(
        'number' => $nb_comment
      );

      $comments_query = new WP_Comment_Query();

      $comments = $comments_query->query( $args );

      if ( $comments ) {

        if ($is_slider && $nb_comment > 1) {

          echo '<div class="box-container-row slider widget__slider js-widget-slider">';

        }

        foreach ( $comments as $comment ) { ?>

          <div class="comment" id="widget-comment-<?php echo esc_attr( $comment->comment_ID ); ?>">

            <div class="comment__container">

              <div class="comment__avatar">
                <?php echo get_avatar( $comment->user_id, '50' ); ?>
              </div>

              <div class="comment__content">

                <span class="comment__author"><?php echo esc_html( $comment->comment_author ); ?></span>

                <span class="comment__about">on
                <?php $postID = $comment->comment_post_ID; ?>
                  <a href="<?php esc_url( the_permalink( $postID ) ); ?>" title="<?php esc_attr( the_title_attribute( $postID ) ); ?>"><?php echo get_the_title( $postID ); ?></a>
                </span>

              </div>

              <div class="comment__text">
                <?php echo azurelo_excerpt($comment->comment_content, 20); ?>
              </div>

              <span class="comment__date"><?php echo esc_html( date(get_option('date_format'), strtotime($comment->comment_date)) ); ?></span>

            </div>

          </div>

        <?php }

        if ($is_slider && $nb_comment > 1) {

          echo '</div>';

        }

      } else { ?>

         <div class="comment">

          <?php echo esc_html_e('No comments found.', 'azurelo'); ?>

        </div> <?php

      }

      echo $after_widget;

    }

  }

?>
