<?php

  /*
    Plugin Name: Azurelo Last Posts Widget
    Version: 1.0
    Description: Display the latest posts.
  */

  function azurelo_latest_load_widget() {
    register_widget( 'azurelo_latest_widget' );
  }

  add_action( 'widgets_init', 'azurelo_latest_load_widget' );

  class azurelo_latest_widget extends WP_Widget {

    function __construct() {
      $widget_ops = array('classname' => 'widget__latest', 'description' => 'Display the latest posts.' );
      parent::__construct('azurelo_latest_widget', 'Azurelo: Last posts', $widget_ops);
    }

    function form($instance) {

      $default = array( 'title' => 'Latest posts', 'nb_post' => '4', 'is_slider' => 'off');
      $instance = wp_parse_args( (array) $instance, $default );

      ?>

        <!-- Title  -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>">Title:
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
          </label>
        </p>

        <!-- Number of posts to shows -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('nb_post') ); ?>">Number to show:
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('nb_post') ); ?>" name="<?php echo esc_attr( $this->get_field_name('nb_post') ); ?>" type="number" min="1" max="10" value="<?php echo esc_attr( (int)$instance['nb_post'] ); ?>" />
          </label>
        </p>

        <!--Use as a slider -->
        <p>
          <label for="<?php echo esc_attr( $this->get_field_id('is_slider') ); ?>">
          <input type="checkbox" id="<?php echo esc_attr( $this->get_field_id('is_slider') ); ?>" name="<?php echo esc_attr( $this->get_field_name('is_slider') ); ?>" <?php checked( (bool) $instance['is_slider'], true ); ?>">
          Use as a slider
        </p>

      <?php
    }

    function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = esc_attr($new_instance['title']);
      $instance['nb_post'] = esc_attr($new_instance['nb_post']);
      $instance['is_slider'] = esc_attr($new_instance['is_slider']);
      return $instance;
    }

    function widget($args, $instance) {

      extract($args, EXTR_SKIP);

      echo $before_widget;

      $nb_post = (isset($instance['nb_post']) ? $instance['nb_post'] : '');
      $is_slider = isset($instance['is_slider']) ? $instance['is_slider'] : '';

      if ( isset($instance['title'])) {
        $title = apply_filters('widget_title', $instance['title']);
        echo $before_title . esc_html( $title ) . $after_title;
      }

      if ($is_slider && $nb_post > 1) {

        echo '<div class="box-container-row slider widget__slider js-widget-slider">';

      } else {

        echo '<div class="box-container-row">';

      }

        $args = array( 'post_type' => 'post', 'showposts' => $nb_post, 'order ' => 'DESC', 'orderby ' => 'post_date', 'ignore_sticky_posts' => 1 );

        $the_query = new WP_Query($args);

        if($the_query -> have_posts()) : while($the_query -> have_posts()) : $the_query -> the_post();

          get_template_part('templates/post', 'small-latest');

        endwhile; endif; wp_reset_postdata();

      echo '</div>';

      echo $after_widget;

    }

  }

?>
